UK2GTFS option updateCachedDataOnLibaryLoad
Source:R/globals.R
UK2GTFS_option_updateCachedDataOnLibaryLoad.Rdsets/gets a logical value which determines if the data cached in the library is checked for update when loaded

R/globals.R
UK2GTFS_option_updateCachedDataOnLibaryLoad.Rdsets/gets a logical value which determines if the data cached in the library is checked for update when loaded