R/get_naptan.R
as_data_table_naptan_stop_point.Rd
Unpacks selected naptan XML doc elements into data.table
as_data_table_naptan_stop_point(doc, stopTypes = c("RLY"))
xml document node
list of stop types to restrict processing to (defaults to railway station)
data table of stop points
RLY stop types include TIPLOC & CRS fields. The quality of the geographic location is better than from BPLAN