Count the number of trips stopping at each stop between two dates
Source:R/stops_per_week_functions.R
gtfs_stop_frequency.RdCount the number of trips stopping at each stop between two dates

R/stops_per_week_functions.R
gtfs_stop_frequency.RdCount the number of trips stopping at each stop between two dates