List the fare products available in a set of NeTEx files
Source:R/netex_fares_match.R
netex_fare_types.RdSummarises a list of parsed NeTEx fare objects so the caller can see which fare types (single / return, adult / child, per line and direction) are present and therefore what can be selected for conversion.