Joins each parsed NeTEx fare object to a route in a GTFS object. The join key is the operator National Operator Code (NeTEx `operator_noc` == GTFS `agency_id`) together with the public line number (NeTEx `line_public_code` == GTFS `route_short_name`). The GTFS `route_id` is generated from the TransXChange ServiceCode and cannot be matched to the NeTEx line id directly, which is why the public codes are used.