As UK2GTFS has large datasets that update separately to the R package they are checked and downloaded at package load time. This function checks for and downloaded any updated to the data.
As UK2GTFS has large datasets that update separately to the R package they are checked and downloaded at package load time. This function checks for and downloaded any updated to the data.