R/globals.R
UK2GTFS_option_updateCachedDataOnLibaryLoad.Rdsets/gets a logical value which determines if the data cached in the library is checked for update when loaded
UK2GTFS_option_updateCachedDataOnLibaryLoad(value)the current option value when called with no arguments, otherwise the result of setting the option
when child processes are initialised we want to suppress this check, so it is also used for that purpose