Download small examples of ATOC CIF and TransXchange files. These are mainly meant for internal testing. But can also be used to check the package is correctly installed.
Download small examples of ATOC CIF and TransXchange files. These are mainly meant for internal testing. But can also be used to check the package is correctly installed.