Download small examples of ATOC CIF and TransXchange files. These are mainly meant for internal testing. But can also be used to check the package is correctly installed.
dl_example_file(path, type = "atoc")TRUE if the download succeeded, called for the side effect of downloading an example file