!WARNING! only the tables: agency, stops, routes, trips, stop_times, calendar, calendar_dates, shapes, frequencies are processed, any other tables in the input timetables are passed through
Arguments
- gtfs_list
a list of gtfs objects to be merged
- force
logical, if TRUE duplicated values are merged taking the fist instance to be the correct instance, in most cases this is ok, but may cause some errors
- quiet
logical, if TRUE less messages
- condenseServicePatterns
logical, if TRUE service patterns across all routes are condensed into a unique set of patterns