R/stops_per_week_functions.R
gtfs_stop_frequency.RdCount the number of trips stopping at each stop between two dates
the stops table with total stop counts and stops per week added
For frequency-based services (frequencies.txt), each trip is counted once per departure implied by its frequency windows.