Trim a GTFS file between two dates
gtfs_trips_per_zone(
gtfs,
zone,
startdate = min(gtfs$calendar$start_date),
enddate = min(gtfs$calendar$start_date) + 31,
zone_id = 1,
by_mode = TRUE,
ncores = 1,
time_bands = list(breaks = c(-1, 6, 10, 15, 18, 22, Inf), labels = c("Night",
"Morning Peak", "Midday", "Afternoon Peak", "Evening", "Night"))
)GTFS object from gtfs_read()
SF data frame of polygons
Start date
End date
Which column in `zone` is the ID column
logical, disaggregate by mode?
numeric, how many cores to use in parallel processing
list with two named vectors breaks and labels. Used to define the time breakdown. Length of breaks must be one greater than length of labels.
a data frame of trips per zone, day of week, and time band
For frequency-based services (frequencies.txt), each departure implied by a frequency window is counted as a separate trip in the time band of its departure time.